Attribute VB_Name = "Module1"
' Lawson Labs, Inc.
' 3239 Phoenixville Pike
' Malvern, PA  19355
' 800 321-5355 or 406 257-5355
' World Wide Web - www.lawsonlabs.com
' Last modified: 11-13-00
' filename: VB5_m203
' requires NT_m203.DLL

Option Explicit

'11-9-00
Public fScanning As Byte

Type M203
    comPort As Integer          ' Currently selected comm port (0 to 3) for COM1 .. COM4
    scanInterval As Double      ' Current scan interval in seconds
    numChannels As Integer      ' Number of scanning channels (always 1 for Model 203)
    tScan As Integer            ' Scan type (always 0 for Model 203)
    scanChan As Integer         ' Current scan mode channel (0,1,6, or 7)
    lastDigInp As Integer       ' Last digital input value
    version As Integer          ' Model 203 version (203)
    pollChan As Integer         ' Current polled mode channel
    subSample As Integer        ' Number of subsamples per conversion 160 for 60HZ, 192 for 50 Hz
    rawCount As Long            ' Last raw count returned from Model 203
    digOutWord As Long          ' Last value sent to Model 203 for digital output (0-255)
    wordCnt As Integer          ' number of bytes in a conversion result (2 = 16-bit, 3 = 24-bit)
    errorType As Long           ' error code returned from DLL
    bU As Long                  ' BiPolar UniPolar Input Range (Not Used on Model 203)
    filter As Integer           ' Input filter selection (not used on Model 203)
    divideBy As Integer         ' Remote (power of 2) division (0 to 7)
    gain As Double              ' Last calculated Gain
    maxRate As Single           ' Maximum sample rate (120 Hz for 60Hz, 100 Hz for 50Hz)
    totalPeriods As Integer     ' (modeRegLo) - Number of conversions per sample
    modeRegLo As Integer        '
    modeRegMid As Integer       ' MSB = Word Length, always 1 (24 bit), remaining bits unused
    modeRegHi As Integer        ' Mode Register High - Unused on Model 203
    baud As Integer             ' BAUD rate code (0-5) 0=9600 bps ... 5=300 bps
    dac1volts As Single         ' Current Voltage for Analog Output 1
    dac2volts As Single         ' Current Voltage for Analog Output 2
    dacEnable As Integer        ' Not Used (DACs always enabled)
    timeBase As Long            ' must be a positive value
    echoTestCount As Long       ' Serial Echo Test Byte Count
    offsetTotal As Long         ' Last calculated Offset
    runningAvg As Long          ' Running Average
    dataAcqMode As Integer      ' 0 = Scanning, 1 = Polled
    inputBuffer As Long         ' receive queue sizes for Windows COMM driver
    wL As Integer               ' Word Length - Always 128 for 24-bit with M203
    gain1 As Single             ' Last calculated Gain
    totalBits As Double         ' Total possible bits of resolution
    scan As Byte
    scan1 As Byte
    scan2 As Byte
    retry As Long               ' Number of SignOn retrys
    ChanChgFlg As Integer
    Voltage As Double
End Type
Public fInvalidChanChange As Boolean
Public fDebugFile As Byte
Public fSignedOn As Boolean

Public DigInToken As Long
Public DacToSet As Long

Public placeholder As Long
Public reserved As Long
Public spare As Long

'following 4 variables for graphic display handling only
Public scandisp As Byte
Public posfs As Long
Public negfs As Long
Public vdiv As Long
Public hdiv As Long

Public CountArray(100) As Double    'Running voltage average array
Public ArrayPointer As Integer      'Running voltage average array pointer
Public CountTotal As Double         'Running voltage average array total
Public ChanChgFlg As Integer        'Channel Change Flag, 1 = Channel has been changed

Public GetConversionInitialized As Boolean
Public frmat As String

Public EchoTestFlg As Integer
Public NewScanBuff(300) As Byte  'buffer for passing one scan from DLL
Public BuffDebugMsg(255) As Byte 'buffer for passing debug text from DLL to app

Public cc(6) As Integer          'control code workspace
Public M_203 As M203             'm203 structured data shared with DLL
Public CfgFileSpec As String     'Config file name
Public localAvg As Integer       'Averaging done in host
Public IdComDev As Long          'Handle to Com-port (not for use in this code)
Public retVal As Integer         'return value for DLL functions
Public WaitTime As Double        'filter settling time in seconds
Public Msg As String             'message string
Public fStopScan As Boolean      'flag to stop scanning
Public hNT_m203_dll              'handle to DLL
'NT_m203.DLL external functions
Declare Function SetPtrs Lib "NT_m203.dll" (ByRef T_M203 As M203, _
            ByRef NewScanBuff As Byte, ByRef BuffDebugMsg As Byte) _
            As Integer
Declare Function ChangeAnalogOutput Lib "NT_m203.dll" (ByVal DacToSet As Integer) _
                                    As Integer
Declare Function ClearVoltageArray Lib "NT_m203.dll" () As Integer

'this group of functions corresponds exactly to commands described in
'the programmmer's reference section of your manual
Declare Function GetDigIn Lib "NT_m203.dll" (ByVal DigInToken As Integer) As Integer
Declare Function SetDigOut Lib "NT_m203.dll" () As Integer
Declare Function GetVer Lib "NT_m203.dll" () As Integer
Declare Function GetConversion Lib "NT_m203.dll" () As Integer
Declare Function SetChanCode Lib "NT_m203.dll" () As Integer
Declare Function GetCheckSum Lib "NT_m203.dll" () As Integer

'establish communications with Model 201 and send all set-up information
Declare Function SignOn Lib "NT_m203.dll" (ByRef EchoTestFlg As Integer, _
                                  ByVal fDebug As Byte) As Integer

'select chan 7, wait, & do offset cal. Select chan 6, wait & do full scale cal.
Declare Function SysCal Lib "NT_m203.dll" () As Integer

'starts type of scan determined by sType
'ScanToken=0x8B; Edge=0; for normal scan
Declare Function StartScanning Lib "NT_m203.dll" ( _
        ByVal ScanToken As Long, ByVal Edge As Long) As Integer
        
Declare Function StopScanning Lib "NT_m203.dll" () As Integer

'fetch one scan, wait scantime first, if one isn't ready. Used usually to
' empty buffer at end of scanning
Declare Function GetOneScan Lib "NT_m203.dll" () As Integer

'5-25-06 following two functions added to similate Model 201
Declare Function GetNumScansInBuffer Lib "NT_m203.dll" () As Long
Declare Sub Gconv Lib "NT_m203.dll" ()


'Declare Function CheckScanTime Lib "NT_m203.dll" (ByRef NewScanInterval As Double, _
'            ByRef MaxTime As Double, ByRef MinTime As Double) As Integer
            
'remove "size" bytes from serial input buffer(normally used for end-of-scan _
            framing token only)
'Declare Sub RemFromBuffer Lib "NT_m203.dll" (ByVal size As Long)

'Declare Function SendADMode Lib "NT_m203.dll" () As Integer
'Declare Function FullScaleCal Lib "NT_m203.dll" () As Integer
'Declare Function OffsetCal Lib "NT_m203.dll" () As Integer

'Windows API external functions
Declare Function MessageBox Lib "user32" Alias "MessageBoxA" _
    (ByVal hwnd As Long, ByVal lpText As String, ByVal lpCaption As String, _
    ByVal wType As Long) As Long
Declare Function GetModuleHandle Lib "kernel32" Alias "GetModuleHandleA" _
                (ByVal lpModuleName As String) As Long
Declare Function FreeLibrary Lib "kernel32" (ByVal hLibModule As Long) As Long

'  Configuration file should be created and tested using the C or
'  Quick Basic driver software. Note that there are various values
'   in the configuration file that aren't used by the 203. They are
'   defined as "Placeholder" in the following file read.
Public Sub ReadCfgFile()
    Dim cf As Long
    Dim sStr As String
    If Right$(App.Path, 1) = "\" Then
        CfgFileSpec = App.Path & "M203.cfg"
    Else
        CfgFileSpec = App.Path & "\M203.cfg"
    End If

    cf = FreeFile
    On Error GoTo NO_FILE
    Open CfgFileSpec For Input As #cf

    ' (6 parameters) Configuration file Line 1
    Input #cf, sStr
    M_203.modeRegHi = Val(sStr)
    Input #cf, sStr
    M_203.modeRegMid = Val(sStr)
    Input #cf, sStr
    M_203.modeRegLo = Val(sStr)
    Input #cf, sStr
    M_203.pollChan = Val(sStr)
    Input #cf, sStr
    M_203.subSample = Val(sStr)
    Line Input #cf, sStr
    M_203.divideBy = Val(sStr)
    'Line Input #cf, sStr

    ' (9 parameters) Configuration file Line 2
    Input #cf, sStr
    M_203.dacEnable = Val(sStr)
    Input #cf, sStr
    M_203.baud = Val(sStr)
    Input #cf, sStr
    M_203.comPort = Val(Mid$(sStr, 4, 1)) - 1

    Input #cf, sStr
    M_203.inputBuffer = Val(sStr)
    If M_203.inputBuffer < 11 Then
        M_203.inputBuffer = 11
    Else
        If M_203.inputBuffer > 32767 Then
            M_203.inputBuffer = 32767
        End If
    End If
    Input #cf, sStr
    spare = Val(sStr)
    Input #cf, sStr
    M_203.bU = Val(sStr)
    Input #cf, sStr
    M_203.gain1 = Val(sStr)
    Input #cf, sStr
    M_203.maxRate = Val(sStr)
    Line Input #cf, sStr
    M_203.wL = Val(sStr)

    ' (4 parameters) Configuration file Line 3
    Input #cf, sStr
    placeholder = Val(sStr)
    Input #cf, sStr
    placeholder = Val(sStr)
    Input #cf, sStr
    placeholder = Val(sStr)
    Line Input #cf, sStr
    placeholder = Val(sStr)

    ' (3 parameters) Configuration file Line 4
    Input #cf, sStr
    placeholder = Val(sStr)
    Input #cf, sStr
    placeholder = Val(sStr)
    Line Input #cf, sStr
    M_203.scanChan = Val(sStr)

    ' (6 parameters) Configuration file Line 5
    Input #cf, sStr
    M_203.scan = Val(sStr)
    Input #cf, sStr
    M_203.scan1 = Val(sStr)
    Input #cf, sStr
    M_203.scan2 = Val(sStr)
    Input #cf, sStr
    M_203.scanInterval = Val(sStr)
    Input #cf, sStr
    M_203.tScan = Val(sStr)
    Line Input #cf, sStr
    reserved = Val(sStr)

    ' (8 parameters) Configuration file Line 6
    Input #cf, sStr
    M_203.dac1volts = Val(sStr)
    Input #cf, sStr
    M_203.dac2volts = Val(sStr)
    Input #cf, sStr
    M_203.totalPeriods = Val(sStr)
    Input #cf, sStr
    If UCase(sStr) = "TEXT" Then
        scandisp = 0
    Else
        scandisp = 1
    End If
    Input #cf, sStr
    posfs = Val(sStr)
    Input #cf, sStr
    negfs = Val(sStr)
    Input #cf, sStr
    vdiv = Val(sStr)
    Line Input #cf, sStr
    hdiv = Val(sStr)

    ' (3 parameters) Configuration file Line 7
    Input #cf, sStr
    M_203.gain = Val(sStr)
    Input #cf, sStr
    M_203.runningAvg = Val(sStr)
    Input #cf, sStr
    M_203.timeBase = Val(sStr)
    Close #cf
    GoTo EXIT_READ_CFG

NO_FILE:
    Close #cf
    MsgDisplay ("File error M203.CFG" _
        & Chr(10) _
        & Chr(10) _
        & Chr(10) _
        & "Locate and place configuration file in" _
        & Chr(10) _
        & Chr(10) _
        & "same directory as application and try again." _
        & Chr(10) _
        & Chr(10) _
        & Chr(10) _
        & "Creating a default configuration" _
        & Chr(10) _
        & Chr(10))
       
    'Set some default parameters
    scandisp = 0             'Text Scan display mode
    reserved = 0
    placeholder = 0
    M_203.comPort = 0        'COM1
    M_203.scanInterval = 1   '1 sec
    M_203.numChannels = 1    '1 channel
    M_203.tScan = 0          '0 Single Channel Scanning
    M_203.scanChan = 7       '0 Input Channel - Scanning
    M_203.lastDigInp = 255   'All High Last digital input value
    M_203.version = 203      'Model 203 version (203)
    M_203.pollChan = 7       '7 Offset Channel
    M_203.subSample = 160    '60 Hz Value, 192 for 50 Hz
    M_203.rawCount = 0       '0 Last raw count
    M_203.digOutWord = 256   '256 Non-Valid Value - Last value sent (0-255)
    M_203.wordCnt = 3        '3 for 24-bit)
    M_203.errorType = 0      'error code returned from DLL
    M_203.bU = 1             'UniPolar = 0, BiPolar=1 (M203 always BiPolar)
    M_203.filter = 0         'Not used
    M_203.divideBy = 0       '0 Remote (power of 2) division (/1)
    M_203.gain1 = 1
    M_203.gain = 1
    M_203.maxRate = 120      'Maximum sample rate (120 Hz for 60Hz)
    M_203.modeRegHi = 0      'Not used
    M_203.modeRegMid = 128   'MSB = 1, (24 bit) word length
    M_203.modeRegLo = 2
    M_203.totalPeriods = 2   '2 for 60 HZ Sample Rate (with 120 maxRate)
    M_203.baud = 0           '0=9600 bps
    M_203.dac1volts = 0      'Current Voltage for Analog Output 1
    M_203.dac2volts = 0      'Current Voltage for Analog Output 2
    M_203.dacEnable = 0      'Not Used
    M_203.timeBase = 96      '256 - SubSample
    M_203.echoTestCount = 0  'Serial Echo Test Byte Count
    M_203.runningAvg = 1
    M_203.dataAcqMode = 1    '1 = Polled
    M_203.wL = 128
    M_203.inputBuffer = 32767
    posfs = 0
    negfs = 0
    vdiv = 0
    hdiv = 0
    
EXIT_READ_CFG:
    On Error GoTo 0
End Sub
Public Sub Wait(WaitTime)
    Dim dblEndTime As Double
    dblEndTime = Timer + WaitTime
    Do While dblEndTime > Timer
        DoEvents
    Loop
End Sub
Public Sub MsgDisplay(Msg)
    Dim retVal As Long
    'MsgBox Msg, vbOK           'this box has no title control
    retVal = MessageBox(0, Msg, "Error ----", 0)
End Sub




